/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;


/**
 * Unit tests for DataServer implementation.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class DataServerTest extends TestCase {
    /**
     * The DataServer instance to test against.
     */
    private DataServer server = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(DataServerTest.class);

        return suite;
    }

    /**
     * Prepares an DataServer instance for testing.
     */
    protected void setUp() {
        server = new SimpleDataServer("type");
    }

    /**
     * Tests the constructor with null type. Expects IllegalArgumentException.
     */
    public void testConstructor_NullType() {
        try {
            new SimpleDataServer(null);
            fail("Creates DataServer with null type");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Tests the constructor with empty type. Expects IllegalArgumentException.
     */
    public void testConstructor_EmptyType() {
        try {
            new SimpleDataServer("");
            fail("Creates DataServer with empty type");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of getJarFile and setJarFile methods with jar file specified. Verifies it by getting the jar file back
     * after setting it.
     */
    public void testGetSetJarFile_Specified() {
        File jarFile = new File("");

        server.setJarFile(jarFile);
        assertEquals("Returns an incorrect jar file", jarFile, server.getJarFile());
    }

    /**
     * Test of getJarFile method with no jar file specified. Should return null.
     */
    public void testGetJarFile_Unspecified() {
        assertNull("Returns an incorrect jar file", server.getJarFile());
    }

    /**
     * A simple implementation of the DataServer class for testing.
     */
    private class SimpleDataServer extends DataServer {
        /**
         * Creates a new instance of DataServer.
         *
         * @param type the type of the server.
         */
        public SimpleDataServer(String type) {
            super(type);
        }

        /**
         * Starts the server. This method should be called before running the tests.
         */
        public void startUp() {
            // empty implementation
        }

        /**
         * Stops the server. This method should be called after running the tests.
         */
        public void shutDown() {
            // empty implementation
        }

        /**
         * Initializes the server with data. This method should be called before running the tests.
         */
        public void initData() {
            // empty implementation
        }

        /**
         * Cleans up the data for the server initialized by the initData() method. This method should be called after
         * running the tests.
         */
        public void cleanUpData() {
            // empty implementation
        }
    }
}
