/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.web;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.tools.ant.BuildFileTest;

import java.io.File;


/**
 * Unit tests for PrepareTestEarTask implementation. The tests consist of two parts: one directly against the
 * PrepareTestEarTask instance, the other indirectly through a sample build file for testing the execute() method.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class PrepareTestEarTaskTest extends BuildFileTest {
    /**
     * The build file used to test for PrepareTestEarTask.
     */
    private static final String BUILD_FILE = "test_files/ServerAppTestTask.xml";

    /**
     * The cactified ear file generated by the task.
     */
    private static final String DEST_EAR_FILE = "test_files/dest.ear";

    /**
     * The PrepareTestEarTask instance to test against.
     */
    private PrepareTestEarTask task = null;

    /**
     * Creates a test of the specified name. Configures the sample build file to run the targets from.
     *
     * @param name the name of the test.
     */
    public PrepareTestEarTaskTest(String name) {
        super(name);
        configureProject(BUILD_FILE);
    }

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(PrepareTestEarTaskTest.class);

        return suite;
    }

    /**
     * Prepares a PrepareTestEarTask instance for testing.
     */
    protected void setUp() {
        task = new PrepareTestEarTask();
    }

    /**
     * Deletes the generated ear file.
     */
    protected void tearDown() {
        new File(DEST_EAR_FILE).delete();
    }

    /**
     * Tests the accessibility of constructor.
     */
    public void testConstructor() {
        new PrepareTestEarTask();
    }

    /**
     * Test of addFileset method with null fileset. Expects IllegalArgumentException.
     */
    public void testAddFileset_NullFileSet() {
        try {
            task.addFileset(null);
            fail("Adds null fileset");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of execute method with no srcfile attribute specified. Expects BuildException.
     */
    public void testExecute_OnUnspecifiedSrcFile() {
        expectBuildException("test_prepareear_no_srcfile",
            "You need to specify either the [srcfile] or the [version] attribute");
    }

    /**
     * Test of execute method with no destfile attribute specified. Expects BuildException.
     */
    public void testExecute_OnUnspecifiedDestFile() {
        expectBuildException("test_prepareear_no_destfile", "Fails to prepare ear file");
    }

    /**
     * Test of execute method with all attributes and nested elements specified. Verifies if the cactified ear file is
     * written to the destination.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public void testExecute_OnSpecifiedAll() throws Exception {
        executeTarget("test_prepareear_all");
        assertTrue("Fails to cactify ear file", new File(DEST_EAR_FILE).exists());
    }
}
