/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.web;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.tools.ant.BuildFileTest;

import java.io.File;


/**
 * Unit tests for PrepareTestWarTask implementation. The tests consist of two parts: one directly against the
 * PrepareTestWarTask instance, the other indirectly through a sample build file for testing the execute() method.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class PrepareTestWarTaskTest extends BuildFileTest {
    /**
     * The build file used to test for PrepareTestWarTask.
     */
    private static final String BUILD_FILE = "test_files/ServerAppTestTask.xml";

    /**
     * The cactified war file generated by the task.
     */
    private static final String DEST_WAR_FILE = "test_files/dest.war";

    /**
     * The PrepareTestWarTask instance to test against.
     */
    private PrepareTestWarTask task = null;

    /**
     * Creates a test of the specified name. Configures the sample build file to run the targets from.
     *
     * @param name the name of the test.
     */
    public PrepareTestWarTaskTest(String name) {
        super(name);
        configureProject(BUILD_FILE);
    }

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(PrepareTestWarTaskTest.class);

        return suite;
    }

    /**
     * Prepares a PrepareTestWarTask instance for testing.
     */
    protected void setUp() {
        task = new PrepareTestWarTask();
    }

    /**
     * Deletes the generated war file.
     */
    protected void tearDown() {
        new File(DEST_WAR_FILE).delete();
    }

    /**
     * Tests the accessibility of constructor.
     */
    public void testConstructor() {
        new PrepareTestWarTask();
    }

    /**
     * Test of addFileset method with null fileset. Expects IllegalArgumentException.
     */
    public void testAddFileset_NullFileSet() {
        try {
            task.addFileset(null);
            fail("Adds null fileset");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of addClasses method with null classes. Expects IllegalArgumentException.
     */
    public void testAddClasses_NullClasses() {
        try {
            task.addClasses(null);
            fail("Adds null classes");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of addLib method with null lib. Expects IllegalArgumentException.
     */
    public void testAddLib_NullLib() {
        try {
            task.addLib(null);
            fail("Adds null lib");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of execute method with no srcfile attribute specified. Expects BuildException.
     */
    public void testExecute_OnUnspecifiedSrcFile() {
        expectBuildException("test_preparewar_no_srcfile",
            "You need to specify either the [srcfile] or the [version] attribute");
    }

    /**
     * Test of execute method with no destfile attribute specified. Expects BuildException.
     */
    public void testExecute_OnUnspecifiedDestFile() {
        expectBuildException("test_preparewar_no_destfile", "Fails to prepare war file");
    }

    /**
     * Test of execute method with all attributes and nested elements specified. Verifies if the cactified war file is
     * written to the destination.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public void testExecute_OnSpecifiedAll() throws Exception {
        executeTarget("test_preparewar_all");
        assertTrue("Fails to cactify war file", new File(DEST_WAR_FILE).exists());
    }
}
